TRANSFER_SHARE_EVENT = [
    {"anonymous": False,
     "inputs": [{"indexed": True, "name": "from_address", "type": "address"},
                {"indexed": True, "name": "to_address", "type": "address"},
                {"indexed": False, "name": "value", "type": "uint256"}],
     "name": "TransferShares",
     "type": "event"}
]
