from defi_services.abis.dex.spookyswap.masterchef_v3_abi import SPOOKYSWAP_MASTERCHEF_V3_ABI

SPOOKY_FTM_V2_INFO = {
    'factory_address': '0x152ee697f2e276fa89e96742e9bb9ab1f2e61be3',
    'master_chef_address': '0x18b4f774fdc7bf685daeef66c2990b1ddd9ea6ad',
    'reward_token': '0x841fad6eae12c286d1fd18d1d525dffa75c7effe',
    'forked': 'uniswap-v2'

}

SPOOKY_FTM_V3_INFO = {
    'master_chef_address': '0x9c9c920e51778c4abf727b8bb223e78132f00aa4',
    'master_chef_abi': SPOOKYSWAP_MASTERCHEF_V3_ABI,
    'forked': 'uniswap-v3'

}
